"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validator = void 0;
class Validator {
    constructor() {
        // Regular expressions
        this.alphabetRegex = /^[a-zA-Z]$/;
        this.emailRegex = /^[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}$/;
        this.passwordRegex = /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[@$!%?&])[A-Za-z\d@$!%?&]{8,}$/;
        this.usernameRegex = /^[a-zA-Z0-9_]{3,16}$/;
        this.urlRegex = /^(https?:\/\/)?([\da-z\.-]+)\.([a-z\.]{2,6})([\/\w \.-])\/?$/;
        this.phoneRegex = /^\+?1?\s*\(?([0-9]{3})\)?[-.\s]?([0-9]{3})[-.\s]?([0-9]{4})$/;
        this.dateRegex = /^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12]\d|3[01])$/;
        this.timeRegex = /^([01]?[0-9]|2[0-3]):[0-5][0-9]$/;
        this.ipRegex = /^(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)$/;
        this.hexColorRegex = /^#?([a-fA-F0-9]{6}|[a-fA-F0-9]{3})$/;
        this.creditCardRegex = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|6(?:011|5[0-9]{2})[0-9]{12}|(?:2131|1800|35\d{3})\d{11})$/;
        this.zipCodeRegex = /^\d{5}(-\d{4})?$/;
        this.ssnRegex = /^(?!000|666)[0-8][0-9]{2}-(?!00)[0-9]{2}-(?!0000)[0-9]{4}$/;
        this.ipv6Regex = /^(([0-9a-fA-F]{1,4}:){7,7}[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,7}:|([0-9a-fA-F]{1,4}:){1,6}:[0-9a-fA-F]{1,4}|([0-9a-fA-F]{1,4}:){1,5}(:[0-9a-fA-F]{1,4}){1,2}|([0-9a-fA-F]{1,4}:){1,4}(:[0-9a-fA-F]{1,4}){1,3}|([0-9a-fA-F]{1,4}:){1,3}(:[0-9a-fA-F]{1,4}){1,4}|([0-9a-fA-F]{1,4}:){1,2}(:[0-9a-fA-F]{1,4}){1,5}|[0-9a-fA-F]{1,4}:((:[0-9a-fA-F]{1,4}){1,6})|:((:[0-9a-fA-F]{1,4}){1,7}|:)|fe80:(:[0-9a-fA-F]{0,4}){0,4}%[0-9a-zA-Z]{1,}|::(ffff(:0{1,4}){0,1}:){0,1}((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])|([0-9a-fA-F]{1,4}:){1,4}:((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9]))$/;
        this.windowsPathRegex = /^[a-zA-Z]:\\(?:[^\\/:?"<>|\r\n]+\\)[^\\/:?"<>|\r\n]$/;
        this.unixPathRegex = /^(\/[^/ ]*)+\/?$/;
        this.slugRegex = /^[a-z0-9]+(?:-[a-z0-9]+)*$/;
        this.htmlTagRegex = /<[^>]*>/g;
        this.lettersAndSpacesRegex = /^[A-Za-z\s]*$/;
        this.numbersOnlyRegex = /^\d+$/;
        this.fileExtensionRegex = /^.+\.(jpg|jpeg|png|gif|pdf)$/;
        this.youtubeVideoIdRegex = /http:\/\/(?:youtu\.be\/|(?:[a-z]{2,3}\.)?youtube\.com\/watch(?:\?|#\!)v=([\w-]{11}).*)/gi;
        this.decimalRegex = /^\d*\.?\d+$/;
        this.negativeDecimalRegex = /^-?\d*\.?\d+$/;
        this.currencyUSDRegex = /^\$\d{1,3}(,\d{3})*(\.\d{2})?$/;
        this.percentageRegex = /^100(\.0{1,2})?$|^\d{1,2}(\.\d{1,2})?$/;
        this.phoneUSRegex = /^\+?1?\s*\(?([0-9]{3})\)?[-.\s]?([0-9]{3})[-.\s]?([0-9]{4})$/;
        this.phoneInternationalRegex = /^\+(?:[0-9] ?){6,14}[0-9]$/;
        this.date_YYYYMMDD_Regex = /^\d{4}-(0[1-9]|1[0-2])-(0[1-9]|[12]\d|3[01])$/;
        this.date_DDMMYYYY_Regex = /^(0[1-9]|[12]\d|3[01])[- /.](0[1-9]|1[0-2])[- /.]\d{4}$/;
        this.time24HRegex = /^([01]?[0-9]|2[0-3]):[0-5][0-9]$/;
        this.time12HRegex = /^(0?[1-9]|1[0-2]):[0-5][0-9] ?[AaPp][Mm]$/;
        this.dateTime_ISO8601_Regex = /^\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d(\.\d+)?(([+-]\d\d:\d\d)|Z)?$/;
        this.domainRegex = /^[a-zA-Z0-9][a-zA-Z0-9-]{1,61}[a-zA-Z0-9]\.[a-zA-Z]{2,}$/;
        this.macAddressRegex = /^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$/;
        this.latitudeRegex = /^(-?[1-8]?\d(?:\.\d{1,6})?|90(?:\.0{1,6})?)$/;
        this.longitudeRegex = /^(-?(?:1[0-7]|[1-9])?\d(?:\.\d{1,6})?|180(?:\.0{1,6})?)$/;
        this.ssnUSRegex = /^(?!000|666)[0-8][0-9]{2}-(?!00)[0-9]{2}-(?!0000)[0-9]{4}$/;
        this.zipUSRegex = /^\d{5}(-\d{4})?$/;
        this.noSpecialCharRegex = /^[A-Za-z0-9\s]*$/;
        this.noConsecutiveSpacesRegex = /^(?!.*\s{2})[A-Za-z0-9\s]*$/;
    }
    isAlphabet(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.alphabetRegex.test(value);
        });
    }
    isEmail(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.emailRegex.test(value);
        });
    }
    isValidPassword(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.passwordRegex.test(value);
        });
    }
    isValidUsername(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.usernameRegex.test(value);
        });
    }
    isValidURL(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.urlRegex.test(value);
        });
    }
    isValidPhone(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.phoneRegex.test(value);
        });
    }
    isValidDate(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dateRegex.test(value);
        });
    }
    isValidTime(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.timeRegex.test(value);
        });
    }
    isValidIP(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ipRegex.test(value);
        });
    }
    isValidHexColor(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.hexColorRegex.test(value);
        });
    }
    isValidCreditCard(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.creditCardRegex.test(value);
        });
    }
    isValidZipCode(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.zipCodeRegex.test(value);
        });
    }
    isValidSSN(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ssnRegex.test(value);
        });
    }
    isValidIPv6(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ipv6Regex.test(value);
        });
    }
    isValidWindowsPath(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.windowsPathRegex.test(value);
        });
    }
    isValidUnixPath(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.unixPathRegex.test(value);
        });
    }
    isValidSlug(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.slugRegex.test(value);
        });
    }
    containsHTMLTag(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.htmlTagRegex.test(value);
        });
    }
    containsOnlyLettersAndSpaces(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.lettersAndSpacesRegex.test(value);
        });
    }
    containsOnlyNumbers(value) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.numbersOnlyRegex.test(value);
        });
    }
    isValidFileExtension(filename) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.fileExtensionRegex.test(filename);
        });
    }
    extractYouTubeVideoId(url) {
        return __awaiter(this, void 0, void 0, function* () {
            const match = url.match(this.youtubeVideoIdRegex);
            return match ? match[1] : null;
        });
    }
    isValidDecimal(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.decimalRegex.test(input);
        });
    }
    isValidNegativeDecimal(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.negativeDecimalRegex.test(input);
        });
    }
    isValidCurrencyUSD(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.currencyUSDRegex.test(input);
        });
    }
    isValidPercentage(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.percentageRegex.test(input);
        });
    }
    isValidPhoneUS(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.phoneUSRegex.test(input);
        });
    }
    isValidPhoneInternational(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.phoneInternationalRegex.test(input);
        });
    }
    isValidDateYYYYMMDD(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.date_YYYYMMDD_Regex.test(input);
        });
    }
    isValidDateDDMMYYYY(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.date_DDMMYYYY_Regex.test(input);
        });
    }
    isValidTime24H(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.time24HRegex.test(input);
        });
    }
    isValidTime12H(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.time12HRegex.test(input);
        });
    }
    isValidDateTimeISO8601(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.dateTime_ISO8601_Regex.test(input);
        });
    }
    isValidDomain(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.domainRegex.test(input);
        });
    }
    isValidMacAddress(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.macAddressRegex.test(input);
        });
    }
    isValidLatitude(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.latitudeRegex.test(input);
        });
    }
    isValidLongitude(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.longitudeRegex.test(input);
        });
    }
    isValidSSNUS(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.ssnUSRegex.test(input);
        });
    }
    isValidZipUS(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.zipUSRegex.test(input);
        });
    }
    isValidNoSpecialChar(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.noSpecialCharRegex.test(input);
        });
    }
    isValidNoConsecutiveSpaces(input) {
        return __awaiter(this, void 0, void 0, function* () {
            return this.noConsecutiveSpacesRegex.test(input);
        });
    }
}
exports.Validator = Validator;
